package models

import (
	"github.com/beego/beego/v2/client/orm"
	"time"
)

type ChartPermissionResp struct {
	ChartPermissionId int    `description:"权限id"`
	PermissionName    string `description:"权限名称"`
}

type ChartPermission struct {
	ChartPermissionId int    `description:"权限id"`
	PermissionName    string `description:"权限名称"`
	IsShowSustainable bool   `description:"是否展示限免标签"`
}

type CompanyReportPermission struct {
	CompanyReportPermissionId int `orm:"column(company_report_permission_id);pk"`
	CompanyId                 int `description:"客户id"`
	ReportPermissionId        int `description:"报告权限id"`
	CreatedTime               time.Time
	LastUpdatedTime           time.Time
	ChartPermissionId         int    `description:"权限id"`
	StartDate                 string `description:"权限开始日期"`
	EndDate                   string `description:"权限结束日期"`
	ProductId                 int    `description:"产品id"`
	ProductName               string `description:"产品名称"`
	ModifyTime                string `description:"修改时间"`
	CompanyContractId         string `description:"合同id"`
	Status                    string `description:"状态  '正式','试用','关闭','永续','潜在' "`
}

type ChartPermissionListResp struct {
	List      []*ChartPermissionResp
	CheckList []int `description:"权限"`
}

func GetChartPermissionReportAll(condition string) (items []*ChartPermissionResp, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM chart_permission WHERE product_id=2 AND is_report=1 AND permission_type!=2 ` + condition + ` ORDER BY sort ASC `
	_, err = o.Raw(sql).QueryRows(&items)
	return
}

func GetCategoryId(chartPermissionId int) (category_id string, err error) {
	o := orm.NewOrm()
	sql := ` SELECT GROUP_CONCAT(a.category_id) AS category_id 
			FROM cygx_report_mapping AS a
			WHERE a.chart_permission_id=? 
			GROUP BY a.chart_permission_id `
	err = o.Raw(sql, chartPermissionId).QueryRow(&category_id)
	return
}

func GetCategoryIdHome(chartPermissionId int) (category_id string, err error) {
	o := orm.NewOrm()
	sql := `SELECT GROUP_CONCAT(a.category_id) AS category_id 
			FROM cygx_report_mapping AS a
			WHERE a.chart_permission_id=? AND a.is_summary = 1
			GROUP BY a.chart_permission_id  `
	err = o.Raw(sql, chartPermissionId).QueryRow(&category_id)
	return
}

func GetChartPermissionById(chartPermissionId int) (item *ChartPermission, err error) {
	o := orm.NewOrm()
	sql := `SELECT * FROM chart_permission WHERE chart_permission_id = ? `
	err = o.Raw(sql, chartPermissionId).QueryRow(&item)
	return
}
